Estimate the optimal dosing interval to consistently achieve a target trough concentration (Cmin)
Source:R/dosing_optim.R
poso_inter_cmin.RdEstimates the optimal dosing interval to consistently achieve a target Cmin, given a dose, a population pharmacokinetic model, a set of individual parameters, and a target concentration.
Usage
poso_inter_cmin(
dat = NULL,
prior_model = NULL,
dose,
target_cmin,
cmt_dose = 1,
endpoint = "Cc",
estim_method = "map",
nocb = FALSE,
p = NULL,
greater_than = TRUE,
starting_interval = 12,
add_dose = 10,
duration = 0,
indiv_param = NULL
)Arguments
- dat
Dataframe. An individual subject dataset following the structure of NONMEM/rxode2 event records.
- prior_model
A
posologyrprior population pharmacokinetics model, a list of six objects.- dose
Numeric. The dose given.
- target_cmin
Numeric. Target trough concentration (Cmin).
- cmt_dose
Character or numeric. The compartment in which the dose is to be administered. Must match one of the compartments in the prior model. Defaults to 1.
- endpoint
Character. The endpoint of the prior model to be optimised for. The default is "Cc", which is the central concentration.
- estim_method
A character string. An estimation method to be used for the individual parameters. The default method "map" is the Maximum A Posteriori estimation, the method "prior" simulates from the prior population model, and "sir" uses the Sequential Importance Resampling algorithm to estimate the a posteriori distribution of the individual parameters. This argument is ignored if
indiv_paramis provided.- nocb
A boolean. for time-varying covariates: the next observation carried backward (nocb) interpolation style, similar to NONMEM. If
FALSE, the last observation carried forward (locf) style will be used. Defaults toFALSE.- p
Numeric. The proportion of the distribution of concentrations to consider for the optimization. Mandatory for
estim_method=sir.- greater_than
A boolean. If
TRUE: targets a dose leading to a proportionpof the concentrations to be greater thantarget_conc. Respectively, lower ifFALSE.- starting_interval
Numeric. Starting inter-dose interval for the optimization algorithm.
- add_dose
Numeric. Additional doses administered at inter-dose interval after the first dose.
- duration
Numeric. Duration of infusion, for zero-order administrations.
- indiv_param
Optional. A set of individual parameters : THETA, estimates of ETA, and covariates.
Value
A list containing the following components:
- interval
Numeric. An inter-dose interval to reach the target trough concentration before each dosing of a multiple dose regimen.
- type_of_estimate
Character string. The type of estimate of the individual parameters. Either a point estimate, or a distribution.
- conc_estimate
A vector of numeric estimates of the conc. Either a single value (for a point estimate of ETA), or a distribution.
- indiv_param
A
data.frame. The set of individual parameters used for the determination of the optimal dose : THETA, estimates of ETA, and covariates
Examples
rxode2::setRxThreads(2L) # limit the number of threads